## Convert To PDF

- et_convert.py

xlsx,xls ->pdf

For example:

```shell
et_convert.py --format "pdf" test.xlsx
```

![](https://fastly.jsdelivr.net/gh/qbmzc/images/2022/202206190956257.png)

[open.wps.cn](https://open.wps.cn/docs/client/wpsLoad)
